littlemcmc.HamiltonianMC
========================

.. currentmodule:: littlemcmc

.. autoclass:: HamiltonianMC

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HamiltonianMC.__init__
      ~HamiltonianMC.reset
      ~HamiltonianMC.reset_tuning
      ~HamiltonianMC.stop_tuning
      ~HamiltonianMC.warnings
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HamiltonianMC.generates_stats
      ~HamiltonianMC.name
      ~HamiltonianMC.stats_dtypes
   
   